Contributing to PLY
===================

PLY is a mature project that no longer makes releases. New features
are no longer being added to it.  However, if you feel that you have
found a bug in PLY or its documentation, please submit an issue or a
pull request.

Important note: The Github repo for PLY always contains the most
up-to-date version of the software.   If you want to use the current
version, you should COPY the contents of the `ply/` directory into
your own project and use it.  There will be no future package-installable
releases of PLY.





